  static ClassDocumentation<StringFragmentation> documentation
    ("The StringFragmentation class is a straight interface to the Lund "
     "string fragmentation routines in Pythia 8.",
     "Hadronization performed according to the "
     "Lund String Fragmentation scheme \\cite{And83} as implemented in "
     "Pythia\\cite{Sjostrand:2007gs,Sjostrand:2006za} version 8.310.",
     "\\bibitem{And83} B.~Andersson, G.~Gustafson, "
     "G.~Ingelman and T.~Sj\\\"ostrand"
     "\n Phys.~Rep.~{\\bf 97} (1983) 31.\n"
     "\\bibitem{Sjostrand:2007gs} T.~Sj\\\"ostrand, S.~Mrenna, P.~Skands, "
     "Comput.~Phys.~Commun.\\ {\\bf 178} (2008) 852.\n"
     "\\bibitem{Sjostrand:2006za} T.~Sj\\\"ostrand, S.~Mrenna, P.~Skands, "
     "JHEP06~(2006)~026.");

  static Switch<StringFragmentation,bool> interfaceHadronLevel_all
    ("HadronLevel_all",
     "  If off then stop the generation after the hard process and  parton-level activity has been generated, but before the  hadron-level steps.  ",
     &StringFragmentation::theHadronLevel_all, true, true, false);
  static SwitchOption interfaceHadronLevel_allOn
    (interfaceHadronLevel_all,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_allOff
    (interfaceHadronLevel_all,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceHadronLevel_Hadronize
    ("HadronLevel_Hadronize",
     "  Master switch for hadronization; on/off = true/false.  Further options are found in the 'Fragmentation' section of the online Pythia8 manual.  ",
     &StringFragmentation::theHadronLevel_Hadronize, true, true, false);
  static SwitchOption interfaceHadronLevel_HadronizeOn
    (interfaceHadronLevel_Hadronize,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_HadronizeOff
    (interfaceHadronLevel_Hadronize,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceHadronLevel_Decay
    ("HadronLevel_Decay",
     "  Master switch for decays; on/off = true/false.  Further options are found in the 'ParticleDecays' section of the online Pythia8 manual.  ",
     &StringFragmentation::theHadronLevel_Decay, true, true, false);
  static SwitchOption interfaceHadronLevel_DecayOn
    (interfaceHadronLevel_Decay,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_DecayOff
    (interfaceHadronLevel_Decay,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceHadronLevel_Rescatter
    ("HadronLevel_Rescatter",
     "  Master switch for hadronic rescattering, following the hadronization;  on/off = true/false.  <note>Note</note>: If this is on, <code>Fragmentation:setVertices</code> and  <code>HadronVertex:rapidDecays</code> are automatically treated as being on,  since they provide spacetime information required by rescattering.  Consider also turning on <code>PartonVertex:setVertex</code>. Further options  are found in the 'HadronicRescattering' section of the online Pythia8 manual.  ",
     &StringFragmentation::theHadronLevel_Rescatter, false, true, false);
  static SwitchOption interfaceHadronLevel_RescatterOn
    (interfaceHadronLevel_Rescatter,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_RescatterOff
    (interfaceHadronLevel_Rescatter,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceHadronLevel_BoseEinstein
    ("HadronLevel_BoseEinstein",
     "  Master switch for the simulation of Bose-Einstein effects;  on/off = true/false. Further options are found  in the 'BoseEinsteinEffects' section of the online Pythia8 manual.  ",
     &StringFragmentation::theHadronLevel_BoseEinstein, false, true, false);
  static SwitchOption interfaceHadronLevel_BoseEinsteinOn
    (interfaceHadronLevel_BoseEinstein,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_BoseEinsteinOff
    (interfaceHadronLevel_BoseEinstein,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceHadronLevel_DeuteronProduction
    ("HadronLevel_DeuteronProduction",
     "  Master switch for the production of deuterons and anti-deuterons in an  event; on/off = true/false. Further options are found  in the 'DeuteronProduction' section of the online Pythia8 manual.  ",
     &StringFragmentation::theHadronLevel_DeuteronProduction, false, true, false);
  static SwitchOption interfaceHadronLevel_DeuteronProductionOn
    (interfaceHadronLevel_DeuteronProduction,
     "On",
     "On",
     true);
  static SwitchOption interfaceHadronLevel_DeuteronProductionOff
    (interfaceHadronLevel_DeuteronProduction,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringZ_aLund
    ("StringZ_aLund",
     "  The \\f$a\\f$ parameter of the Lund symmetric fragmentation function.  ",
     &StringFragmentation::theStringZ_aLund, 0.68, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_bLund
    ("StringZ_bLund",
     "  The \\f$b\\f$ parameter of the Lund symmetric fragmentation function.  ",
     &StringFragmentation::theStringZ_bLund, 0.98, 0.2, 2.0,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringZ_deriveBLund
    ("StringZ_deriveBLund",
     "  When set to <code>on</code>, the \\f$b\\f$ parameter is treated as a  derived quantity; i.e., the value of <code>StringZ:bLund</code> is  ignored in favour of the <code>StringZ:avgZLund</code> parameter  below. (The <code>StringZ:bLund</code> parameter is then also reset to  the derived value so that it can be queried after initialisation, if  desired.)  ",
     &StringFragmentation::theStringZ_deriveBLund, false, true, false);
  static SwitchOption interfaceStringZ_deriveBLundOn
    (interfaceStringZ_deriveBLund,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_deriveBLundOff
    (interfaceStringZ_deriveBLund,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringZ_avgZLund
    ("StringZ_avgZLund",
     "  When <code>StringZ:deriveBLund</code> is set to <code>on</code>,  this parameter specifies the average of the fragmentation function  for primary rho mesons, evaluated at  \\f$mT^2 = mRho^2 + 2<code>StringPT:sigma</code>^2\\f$.  The appropriate \\f$b\\f$-parameter value is computed automatically  during initialisation and the <code>StringZ:bLund</code> parameter is  updated accordingly. Note that the derived value is allowed to exceed  the nominal limits given for <code>bLund</code> above. This is intended  to allow fits to see the functional behaviour even outside the nominal  limits.  ",
     &StringFragmentation::theStringZ_avgZLund, 0.55, 0.30, 0.70,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_aExtraSQuark
    ("StringZ_aExtraSQuark",
     "  allows a larger \\f$a\\f$ for s quarks, with total  \\f$a = aLund + aExtraSQuark\\f$.  ",
     &StringFragmentation::theStringZ_aExtraSQuark, 0.0, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_aExtraDiquark
    ("StringZ_aExtraDiquark",
     "  allows a larger \\f$a\\f$ for diquarks, with total  \\f$a = aLund + aExtraDiquark\\f$.  ",
     &StringFragmentation::theStringZ_aExtraDiquark, 0.97, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_rFactC
    ("StringZ_rFactC",
     "  \\f$r_c\\f$, i.e. the above parameter for \\f$c\\f$ quarks.  ",
     &StringFragmentation::theStringZ_rFactC, 1.32, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_rFactB
    ("StringZ_rFactB",
     "  \\f$r_b\\f$, i.e. the above parameter for \\f$b\\f$ quarks.  ",
     &StringFragmentation::theStringZ_rFactB, 0.855, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_rFactH
    ("StringZ_rFactH",
     "  \\f$r_h\\f$, i.e. the above parameter for heavier hypothetical quarks,  or in general any new coloured particle long-lived enough to hadronize.  ",
     &StringFragmentation::theStringZ_rFactH, 1.0, 0.0, 2.0,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringZ_useNonstandardC
    ("StringZ_useNonstandardC",
     "  use the above nonstandard Lund ansatz for \\f$c\\f$ quarks.  ",
     &StringFragmentation::theStringZ_useNonstandardC, false, true, false);
  static SwitchOption interfaceStringZ_useNonstandardCOn
    (interfaceStringZ_useNonstandardC,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_useNonstandardCOff
    (interfaceStringZ_useNonstandardC,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceStringZ_useNonstandardB
    ("StringZ_useNonstandardB",
     "  use the above nonstandard Lund ansatz for \\f$b\\f$ quarks.  ",
     &StringFragmentation::theStringZ_useNonstandardB, false, true, false);
  static SwitchOption interfaceStringZ_useNonstandardBOn
    (interfaceStringZ_useNonstandardB,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_useNonstandardBOff
    (interfaceStringZ_useNonstandardB,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceStringZ_useNonstandardH
    ("StringZ_useNonstandardH",
     "  use the above nonstandard Lund ansatz for hypothetical heavier quarks.  ",
     &StringFragmentation::theStringZ_useNonstandardH, false, true, false);
  static SwitchOption interfaceStringZ_useNonstandardHOn
    (interfaceStringZ_useNonstandardH,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_useNonstandardHOff
    (interfaceStringZ_useNonstandardH,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringZ_aNonstandardC
    ("StringZ_aNonstandardC",
     "  The \\f$a\\f$ parameter in the nonstandard Lund ansatz for   \\f$c\\f$ quarks.  ",
     &StringFragmentation::theStringZ_aNonstandardC, 0.3, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_aNonstandardB
    ("StringZ_aNonstandardB",
     "  The \\f$a\\f$ parameter in the nonstandard Lund ansatz for   \\f$b\\f$ quarks.  ",
     &StringFragmentation::theStringZ_aNonstandardB, 0.3, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_aNonstandardH
    ("StringZ_aNonstandardH",
     "  The \\f$a\\f$ parameter in the nonstandard Lund ansatz for  hypothetical heavier quarks.  ",
     &StringFragmentation::theStringZ_aNonstandardH, 0.3, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_bNonstandardC
    ("StringZ_bNonstandardC",
     "  The \\f$b\\f$ parameter in the nonstandard Lund ansatz for  \\f$c\\f$ quarks.  ",
     &StringFragmentation::theStringZ_bNonstandardC, 0.8, 0.2, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_bNonstandardB
    ("StringZ_bNonstandardB",
     "  The \\f$b\\f$ parameter in the nonstandard Lund ansatz for  \\f$b\\f$ quarks.  ",
     &StringFragmentation::theStringZ_bNonstandardB, 0.8, 0.2, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_bNonstandardH
    ("StringZ_bNonstandardH",
     "  The \\f$b\\f$ parameter in the nonstandard Lund ansatz for  hypothetical heavier quarks.  ",
     &StringFragmentation::theStringZ_bNonstandardH, 0.8, 0.2, 2.0,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringZ_usePetersonC
    ("StringZ_usePetersonC",
     "  use Peterson for \\f$c\\f$ quarks.  ",
     &StringFragmentation::theStringZ_usePetersonC, false, true, false);
  static SwitchOption interfaceStringZ_usePetersonCOn
    (interfaceStringZ_usePetersonC,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_usePetersonCOff
    (interfaceStringZ_usePetersonC,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceStringZ_usePetersonB
    ("StringZ_usePetersonB",
     "  use Peterson for \\f$b\\f$ quarks.  ",
     &StringFragmentation::theStringZ_usePetersonB, false, true, false);
  static SwitchOption interfaceStringZ_usePetersonBOn
    (interfaceStringZ_usePetersonB,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_usePetersonBOff
    (interfaceStringZ_usePetersonB,
     "Off",
     "Off",
     false);

  static Switch<StringFragmentation,bool> interfaceStringZ_usePetersonH
    ("StringZ_usePetersonH",
     "  use Peterson for hypothetical heavier quarks.  ",
     &StringFragmentation::theStringZ_usePetersonH, false, true, false);
  static SwitchOption interfaceStringZ_usePetersonHOn
    (interfaceStringZ_usePetersonH,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringZ_usePetersonHOff
    (interfaceStringZ_usePetersonH,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringZ_epsilonC
    ("StringZ_epsilonC",
     "  \\f$epsilon_c\\f$, i.e. the above parameter for \\f$c\\f$ quarks.  ",
     &StringFragmentation::theStringZ_epsilonC, 0.05, 0.01, 0.25,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_epsilonB
    ("StringZ_epsilonB",
     "  \\f$epsilon_b\\f$, i.e. the above parameter for \\f$b\\f$ quarks.  ",
     &StringFragmentation::theStringZ_epsilonB, 0.005, 0.001, 0.025,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringZ_epsilonH
    ("StringZ_epsilonH",
     "  \\f$epsilon_h\\f$, i.e. the above parameter for hypothetical heavier  quarks, normalized to the case where \\f$m_h = m_b\\f$. The actually  used parameter is then \\f$epsilon = epsilon_h * (m_b^2 / m_h^2)\\f$.  This allows a sensible scaling to a particle with an unknown higher  mass without the need for a user intervention.  ",
     &StringFragmentation::theStringZ_epsilonH, 0.005, 0.0001, 0.25,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringPT_thermalModel
    ("StringPT_thermalModel",
     "  If switched off the quark \\f$pT\\f$ is generated according to  the traditional Gaussion distribution in \\f$p_x\\f$ and \\f$p_y\\f$  separately. If switched on, the new \"thermal model\" <ref>Fis16</ref>  is instead used, wherein the quark \\f$pT\\f$ is generated such that the  resulting hadron receives a \\f$pT\\f$ according to an exponential  distribution. Also the hadronic composition is affected, see further  below.  ",
     &StringFragmentation::theStringPT_thermalModel, false, true, false);
  static SwitchOption interfaceStringPT_thermalModelOn
    (interfaceStringPT_thermalModel,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringPT_thermalModelOff
    (interfaceStringPT_thermalModel,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringPT_sigma
    ("StringPT_sigma",
     "  the width \\f$sigma\\f$ in the fragmentation process.  ",
     &StringFragmentation::theStringPT_sigma, 0.335, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_enhancedFraction
    ("StringPT_enhancedFraction",
     "  \\f$enhancedFraction\\f$,the fraction of string breaks with enhanced  width.  ",
     &StringFragmentation::theStringPT_enhancedFraction, 0.01, 0.0, 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_enhancedWidth
    ("StringPT_enhancedWidth",
     "  \\f$enhancedWidth\\f$,the enhancement of the width in this fraction.  ",
     &StringFragmentation::theStringPT_enhancedWidth, 2.0, 1.0, 10.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_widthPreStrange
    ("StringPT_widthPreStrange",
     "  Prefactor multiplying the Gaussian width for strange quarks.  ",
     &StringFragmentation::theStringPT_widthPreStrange, 1.0, 1.0, 10.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_widthPreDiquark
    ("StringPT_widthPreDiquark",
     "  Prefactor multiplying the Gaussian width for diquarks. In case of  diquarks with one or two strange quarks the prefactor is calculated by  multiplying \\f$widthPreDiquark\\f$ once or twice respectively with  \\f$widthPreStrange\\f$.  ",
     &StringFragmentation::theStringPT_widthPreDiquark, 1.0, 1.0, 10.0,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringPT_mT2suppression
    ("StringPT_mT2suppression",
     "  If switched on the flavour composition is chosen based on the hadronic  transverse mass, \\f$mT^2_had\\f$, and not based on the quark masses.  This implies a mass suppression factor \\f$exp(-m_had^2 / 2 sigma^2) \\f$.  ",
     &StringFragmentation::theStringPT_mT2suppression, false, true, false);
  static SwitchOption interfaceStringPT_mT2suppressionOn
    (interfaceStringPT_mT2suppression,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringPT_mT2suppressionOff
    (interfaceStringPT_mT2suppression,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringPT_temperature
    ("StringPT_temperature",
     "  the temperature \\f$T\\f$ in the fragmentation process.  ",
     &StringFragmentation::theStringPT_temperature, 0.21, 0.1, 0.5,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_tempPreFactor
    ("StringPT_tempPreFactor",
     "  Temperature prefactor for strange quarks and diquarks. Default is  determined to have the same average \\f$pT\\f$ in \\f$u/d &rarr; s\\f$  and \\f$s &rarr; u/d\\f$ transistions.  ",
     &StringFragmentation::theStringPT_tempPreFactor, 1.21, 1.0, 1.5,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringPT_closePacking
    ("StringPT_closePacking",
     "  If switched on then the two following parameters modify either  <code>StringPT:sigma</code> or <code>StringPT:temperature</code>,  respectively. Normally only one of the options below would be used,  but technically both are allowed and then combine multiplicatively.  ",
     &StringFragmentation::theStringPT_closePacking, false, true, false);
  static SwitchOption interfaceStringPT_closePackingOn
    (interfaceStringPT_closePacking,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringPT_closePackingOff
    (interfaceStringPT_closePacking,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringPT_expMPI
    ("StringPT_expMPI",
     "  Exponent to the number of MPIs. The width/temparture will get the  prefactor \\f$N(MPI)^expMPI\\f$.  ",
     &StringFragmentation::theStringPT_expMPI, 0.0, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringPT_expNSP
    ("StringPT_expNSP",
     "  Exponent for the number of effective nearby string pieces, calculated as  <eq>      N(NSP) =1 + (N<sub>string</sub>-1)/(1+p<sup>2</sup><sub>T had</sub>/      p<sup>2</sup><sub>T 0</sub>) ,  </eq>  where \\f$p<sup>2</sup><sub>T had</sub> \\f$ is the transverse  momentum of the next produced hadron, estimated based on an educated  guess of its momentum, and \\f$p<sup>2</sup><sub>T 0</sub>\\f$ is the  MPI regularization parameter <code>MultipartonInteractions:pT0Ref</code>.  The width/temperature will get the prefactor \\f$N(NSP)^expNSP\\f$.  ",
     &StringFragmentation::theStringPT_expNSP, 0.13, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_stopMass
    ("StringFragmentation_stopMass",
     "  Is used to define a \\f$W_min = m_q1 + m_q2 + stopMass\\f$,  where \\f$m_q1\\f$ and \\f$m_q2\\f$ are the masses of the two  current endpoint quarks or diquarks.  ",
     &StringFragmentation::theStringFragmentation_stopMass, 1.0, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_stopNewFlav
    ("StringFragmentation_stopNewFlav",
     "  Add to \\f$W_min\\f$ an amount \\f$stopNewFlav * m_q_last\\f$,  where \\f$q_last\\f$ is the last \\f$q qbar\\f$ pair produced  between the final two hadrons.  ",
     &StringFragmentation::theStringFragmentation_stopNewFlav, 2.0, 0.0, 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_stopSmear
    ("StringFragmentation_stopSmear",
     "  The \\f$W_min\\f$ above is then smeared uniformly in the range  \\f$W_min_smeared = W_min * [ 1 - stopSmear, 1 + stopSmear ]\\f$.  ",
     &StringFragmentation::theStringFragmentation_stopSmear, 0.2, 0.0, 0.5,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringFragmentation_TraceColours
    ("StringFragmentation_TraceColours",
     "  In some cases it is interesting to trace the primary hadrons back  to the string pieces from which they were  formed. If <code>StringFragmentation:TraceColours</code> is switched  <code>on</code>, this is done by setting colour and anticolour  indices for the primary hadrons to the indices of the string piece  where the corresponding break-ups are assumed to have happened. To  avoid the possible confusion of having colour indices on colour  singlet particles, this flag is by default <code>off</code>.  ",
     &StringFragmentation::theStringFragmentation_TraceColours, false, true, false);
  static SwitchOption interfaceStringFragmentation_TraceColoursOn
    (interfaceStringFragmentation_TraceColours,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringFragmentation_TraceColoursOff
    (interfaceStringFragmentation_TraceColours,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceHadronLevel_mStringMin
    ("HadronLevel_mStringMin",
     "  Decides whether a partonic system should be considered as a normal  string or a ministring, the latter only producing one or two primary  hadrons. The system mass should be above \\f$mStringMin\\f$ plus the  sum of quark/diquark constituent masses for a normal string description,  else the ministring scenario is used.  ",
     &StringFragmentation::theHadronLevel_mStringMin, 1., 0.5, 1.5,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceFragmentationSystems_mJoin
    ("FragmentationSystems_mJoin",
     "  When two colour-connected partons are very nearby, with at least  one being a gluon, they can be joined into one, to avoid technical  problems of very small string regions. The requirement for joining is  that the invariant mass of the pair is below \\f$mJoin\\f$, where a  gluon only counts with half its momentum, i.e. with its contribution  to the string region under consideration. (Note that, for technical  reasons, the 0.2 GeV lower limit is de facto hardcoded.)  ",
     &StringFragmentation::theFragmentationSystems_mJoin, 0.3, 0.2, 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceFragmentationSystems_mJoinJunction
    ("FragmentationSystems_mJoinJunction",
     "  When the invariant mass of two of the quarks in a three-quark junction  string system becomes too small, the system is simplified to a  quark-diquark simple string. The requirement for this simplification  is that the diquark mass, minus the two quark masses, falls below  \\f$mJoinJunction\\f$. Gluons on the string between the junction and  the respective quark, if any, are counted as part of the quark  four-momentum. Those on the two combined legs are clustered with the  diquark when it is formed.  ",
     &StringFragmentation::theFragmentationSystems_mJoinJunction, 1.0, 0.5, 2.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,int> interfaceMiniStringFragmentation_nTry
    ("MiniStringFragmentation_nTry",
     "  Whenever the machinery is called, first this many attempts are made  to pick two hadrons that the system fragments to. If the hadrons are  too massive the attempt will fail, but a new subsequent try could  involve other flavour and hadrons and thus still succeed.  After \\f$nTry\\f$ attempts, instead an attempt is made to produce a  single hadron from the system. Should also this fail, some further  attempts at obtaining two hadrons will be made before eventually  giving up.  ",
     &StringFragmentation::theMiniStringFragmentation_nTry, 2, 1, 10,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_eNormJunction
    ("StringFragmentation_eNormJunction",
     "  Used to find the effective rest frame of the junction, which is  complicated when the three string legs may contain additional  gluons between the junction and the endpoint. To this end,  a pull is defined as a weighed sum of the momenta on each leg,  where the weight is \\f$exp(- eSum / eNormJunction)\\f$, with  \\f$eSum\\f$ the summed energy of all partons closer to the junction  than the currently considered one (in the junction rest frame).  Should in principle be (close to) \\f$sqrt((1 + a) / b)\\f$, with  \\f$a\\f$ and \\f$b\\f$ the parameters of the Lund symmetric  fragmentation function.  ",
     &StringFragmentation::theStringFragmentation_eNormJunction, 2.0, 0.5, 10,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_eBothLeftJunction
    ("StringFragmentation_eBothLeftJunction",
     "  Retry (up to 10 times) when the first two considered strings in to a  junction both have a remaining energy (in the junction rest frame)  above this number.  ",
     &StringFragmentation::theStringFragmentation_eBothLeftJunction, 1.0, 0.5, 0.0,
     true, false, Interface::lowerlim);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_eMaxLeftJunction
    ("StringFragmentation_eMaxLeftJunction",
     "  Retry (up to 10 times) when the first two considered strings in to a  junction has a highest remaining energy (in the junction rest frame)  above a random energy evenly distributed between  \\f$eBothLeftJunction\\f$ and  \\f$eBothLeftJunction + eMaxLeftJunction\\f$  (drawn anew for each test).  ",
     &StringFragmentation::theStringFragmentation_eMaxLeftJunction, 10.0, 0., 0.0,
     true, false, Interface::lowerlim);

  static Parameter<StringFragmentation,double> interfaceStringFragmentation_eMinLeftJunction
    ("StringFragmentation_eMinLeftJunction",
     "  Retry (up to 10 times) when the invariant mass-squared of the final leg  and the leftover momentum of the first two treated legs falls below  \\f$eMinLeftJunction\\f$ times the energy of the final leg (in the  junction rest frame).  ",
     &StringFragmentation::theStringFragmentation_eMinLeftJunction, 0.2, 0., 0.0,
     true, false, Interface::lowerlim);

  static Parameter<StringFragmentation,double> interfaceStringFlav_probStoUD
    ("StringFlav_probStoUD",
     "  the suppression of \\f$s\\f$ quark production relative to ordinary  \\f$u\\f$ or \\f$d\\f$ one.  ",
     &StringFragmentation::theStringFlav_probStoUD, 0.217, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_probQQtoQ
    ("StringFlav_probQQtoQ",
     "  the suppression of diquark production relative to quark production,  i.e. of baryon relative to meson production.  ",
     &StringFragmentation::theStringFlav_probQQtoQ, 0.081, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_probSQtoQQ
    ("StringFlav_probSQtoQQ",
     "  the suppression of strange diquark production relative to light  diquark production, over and above the one already given by  <code>probStoU</code>.  ",
     &StringFragmentation::theStringFlav_probSQtoQQ, 0.915, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_probQQ1toQQ0
    ("StringFlav_probQQ1toQQ0",
     "  the suppression of spin 1 diquark production relative to spin 0 one,  apart from the factor of 3 enhancement of spin 1 from counting the  number of states.  ",
     &StringFragmentation::theStringFlav_probQQ1toQQ0, 0.0275, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonUDvector
    ("StringFlav_mesonUDvector",
     "  the relative production ratio vector/pseudoscalar for light  (\\f$u\\f$, \\f$d\\f$) mesons.  ",
     &StringFragmentation::theStringFlav_mesonUDvector, 0.50, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonSvector
    ("StringFlav_mesonSvector",
     "  the relative production ratio vector/pseudoscalar for strange mesons.  ",
     &StringFragmentation::theStringFlav_mesonSvector, 0.55, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonCvector
    ("StringFlav_mesonCvector",
     "  the relative production ratio vector/pseudoscalar for charm mesons.  ",
     &StringFragmentation::theStringFlav_mesonCvector, 0.88, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonBvector
    ("StringFlav_mesonBvector",
     "  the relative production ratio vector/pseudoscalar for bottom mesons.  ",
     &StringFragmentation::theStringFlav_mesonBvector, 2.20, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_thetaPS
    ("StringFlav_thetaPS",
     "  gives the mixing angle \\f$theta_PS\\f$ in the pseudoscalar meson sector  (which is rather poorly determined), expressed in degrees.  Here \\f$f\\f$ is associated with \\f$eta'\\f$ and \\f$f'\\f$ with  \\f$eta\\f$. (This standard but counterintuitive choice is fixed up  in the code by replacing \\f$alpha &rarr; 90^0 - alpha\\f$ so that  \\f$eta &harr; eta'\\f$; relative signs do not matter since we are  interested in probabilities only.)  ",
     &StringFragmentation::theStringFlav_thetaPS, -15., -90., 90.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_thetaV
    ("StringFlav_thetaV",
     "  gives the mixing angle \\f$theta_V\\f$ in the vector meson sector  (which is somewhat better determined), expressed in degrees.  Here \\f$f\\f$ is associated with \\f$omega\\f$ and \\f$f'\\f$  with \\f$phi\\f$.  ",
     &StringFragmentation::theStringFlav_thetaV, 36., -90., 90.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_etaSup
    ("StringFlav_etaSup",
     "  the additional suppression of \\f$eta\\f$ production, multiplying the  normal production probability. Thus 0 means no \\f$eta\\f$ at all  are produced, while 1 means full rate.  ",
     &StringFragmentation::theStringFlav_etaSup, 0.60, 0., 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_etaPrimeSup
    ("StringFlav_etaPrimeSup",
     "  the additional suppression of \\f$eta'\\f$ production, multiplying the  normal production probability. Thus 0 means no \\f$eta'\\f$ at all  are produced, while 1 means full rate.  ",
     &StringFragmentation::theStringFlav_etaPrimeSup, 0.12, 0., 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonUDL1S0J1
    ("StringFlav_mesonUDL1S0J1",
     "  the relative pseudovector production ratio  \\f$(L=1,S=0,J=1)\\f$/pseudoscalar  for light (\\f$u\\f$, \\f$d\\f$) mesons.  ",
     &StringFragmentation::theStringFlav_mesonUDL1S0J1, 0.0, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonUDL1S1J0
    ("StringFlav_mesonUDL1S1J0",
     "  the relative scalar production ratio  \\f$(L=1,S=1,J=0)\\f$/pseudoscalar  for light (\\f$u\\f$, \\f$d\\f$) mesons.  ",
     &StringFragmentation::theStringFlav_mesonUDL1S1J0, 0.0, 0., 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonUDL1S1J1
    ("StringFlav_mesonUDL1S1J1",
     "  the relative pseudovector production ratio  \\f$(L=1,S=1,J=1)\\f$/pseudoscalar  for light (\\f$u\\f$, \\f$d\\f$) mesons.  ",
     &StringFragmentation::theStringFlav_mesonUDL1S1J1, 0.0, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonUDL1S1J2
    ("StringFlav_mesonUDL1S1J2",
     "  the relative tensor production ratio  \\f$(L=1,S=1,J=2)\\f$/pseudoscalar  for light (\\f$u\\f$, \\f$d\\f$) mesons.  ",
     &StringFragmentation::theStringFlav_mesonUDL1S1J2, 0.0, 0., 5.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonSL1S0J1
    ("StringFlav_mesonSL1S0J1",
     "  the relative pseudovector production ratio  \\f$(L=1,S=0,J=1)\\f$/pseudoscalar  for strange mesons.  ",
     &StringFragmentation::theStringFlav_mesonSL1S0J1, 0.0, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonSL1S1J0
    ("StringFlav_mesonSL1S1J0",
     "  the relative scalar production ratio  \\f$(L=1,S=1,J=0)\\f$/pseudoscalar  for strange mesons.  ",
     &StringFragmentation::theStringFlav_mesonSL1S1J0, 0.0, 0., 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonSL1S1J1
    ("StringFlav_mesonSL1S1J1",
     "  the relative pseudovector production ratio  \\f$(L=1,S=1,J=1)\\f$/pseudoscalar  for strange mesons.  ",
     &StringFragmentation::theStringFlav_mesonSL1S1J1, 0.0, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonSL1S1J2
    ("StringFlav_mesonSL1S1J2",
     "  the relative tensor production ratio  \\f$(L=1,S=1,J=2)\\f$/pseudoscalar  for strange mesons.  ",
     &StringFragmentation::theStringFlav_mesonSL1S1J2, 0.0, 0., 5.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonCL1S0J1
    ("StringFlav_mesonCL1S0J1",
     "  the relative pseudovector production ratio  \\f$(L=1,S=0,J=1)\\f$/pseudoscalar  for charm mesons.  ",
     &StringFragmentation::theStringFlav_mesonCL1S0J1, 0.0, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonCL1S1J0
    ("StringFlav_mesonCL1S1J0",
     "  the relative scalar production ratio  \\f$(L=1,S=1,J=0)\\f$/pseudoscalar  for charm mesons.  ",
     &StringFragmentation::theStringFlav_mesonCL1S1J0, 0.0, 0., 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonCL1S1J1
    ("StringFlav_mesonCL1S1J1",
     "  the relative pseudovector production ratio  \\f$(L=1,S=1,J=1)\\f$/pseudoscalar  for charm mesons.  ",
     &StringFragmentation::theStringFlav_mesonCL1S1J1, 0.0, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonCL1S1J2
    ("StringFlav_mesonCL1S1J2",
     "  the relative tensor production ratio  \\f$(L=1,S=1,J=2)\\f$/pseudoscalar  for charm mesons.  ",
     &StringFragmentation::theStringFlav_mesonCL1S1J2, 0.0, 0., 5.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonBL1S0J1
    ("StringFlav_mesonBL1S0J1",
     "  the relative pseudovector production ratio  \\f$(L=1,S=0,J=1)\\f$/pseudoscalar  for bottom mesons.  ",
     &StringFragmentation::theStringFlav_mesonBL1S0J1, 0.0, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonBL1S1J0
    ("StringFlav_mesonBL1S1J0",
     "  the relative scalar production ratio  \\f$(L=1,S=1,J=0)\\f$/pseudoscalar  for bottom mesons.  ",
     &StringFragmentation::theStringFlav_mesonBL1S1J0, 0.0, 0., 1.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonBL1S1J1
    ("StringFlav_mesonBL1S1J1",
     "  the relative pseudovector production ratio  \\f$(L=1,S=1,J=1)\\f$/pseudoscalar  for bottom mesons.  ",
     &StringFragmentation::theStringFlav_mesonBL1S1J1, 0.0, 0., 3.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_mesonBL1S1J2
    ("StringFlav_mesonBL1S1J2",
     "  the relative tensor production ratio  \\f$(L=1,S=1,J=2)\\f$/pseudoscalar  for bottom mesons.  ",
     &StringFragmentation::theStringFlav_mesonBL1S1J2, 0.0, 0., 5.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_thetaL1S0J1
    ("StringFlav_thetaL1S0J1",
     "  gives the mixing angle \\f$theta\\f$ in the \\f$(L=1,S=0,J=1)\\f$  pseudovector meson sector, expressed in degrees.  ",
     &StringFragmentation::theStringFlav_thetaL1S0J1, 35.3, -90., 90.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_thetaL1S1J0
    ("StringFlav_thetaL1S1J0",
     "  gives the mixing angle \\f$theta\\f$ in the \\f$(L=1,S=1,J=0)\\f$  scalar meson sector, expressed in degrees.  ",
     &StringFragmentation::theStringFlav_thetaL1S1J0, 35.3, -90., 90.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_thetaL1S1J1
    ("StringFlav_thetaL1S1J1",
     "  gives the mixing angle \\f$theta\\f$ in the \\f$(L=1,S=1,J=1)\\f$  pseudovector meson sector, expressed in degrees.  ",
     &StringFragmentation::theStringFlav_thetaL1S1J1, 35.3, -90., 90.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_thetaL1S1J2
    ("StringFlav_thetaL1S1J2",
     "  gives the mixing angle \\f$theta\\f$ in the \\f$(L=1,S=1,J=2)\\f$  tensor meson sector, expressed in degrees.  ",
     &StringFragmentation::theStringFlav_thetaL1S1J2, 28.0, -90., 90.,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_decupletSup
    ("StringFlav_decupletSup",
     "  the suppression, relative to default SU(6) factors, of decuplet  baryon production. Default corresponds to no suppression, while 0  corresponds to no decuplet production at all.  ",
     &StringFragmentation::theStringFlav_decupletSup, 1.0, 0.0, 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_popcornRate
    ("StringFlav_popcornRate",
     "  gives the relative rates of \\f$B Bbar\\f$ and \\f$B M Bbar\\f$  production, roughly as  <eq>  Prob(B M Bbar) / (Prob(B Bbar) + Prob(B M Bbar)) =  popcornRate / (0.5 + popcornRate)  </eq>  (the complete expression depends on all the quark and diquark production  parameters and is therefore not so useful).  ",
     &StringFragmentation::theStringFlav_popcornRate, 0.5, 0., 2.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_popcornSpair
    ("StringFlav_popcornSpair",
     "  extra suppression for having an \\f$s sbar\\f$ pair shared between  the \\f$B\\f$ and \\f$Bbar\\f$ in a \\f$B M Bbar\\f$ configuration.  ",
     &StringFragmentation::theStringFlav_popcornSpair, 0.9, 0., 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_popcornSmeson
    ("StringFlav_popcornSmeson",
     "  extra suppression for having a strange meson \\f$M\\f$ in a  \\f$B M Bbar\\f$ configuration.  ",
     &StringFragmentation::theStringFlav_popcornSmeson, 0.5, 0., 1.0,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringFlav_suppressLeadingB
    ("StringFlav_suppressLeadingB",
     "  Suppress leading-baryon production.  <option value=\"off\">No suppression.</option>  <option value=\"on\">Suppress the production of a diquark in the string  breaking closest to a quark end of a string, by either of the factors  below. This suppresses the production of first-rank baryons by the same  amount. Indirectly also the second-rank and, if popcorn production is  switched on, third-rank (anti)baryon production is affected. </option>  ",
     &StringFragmentation::theStringFlav_suppressLeadingB, false, true, false);
  static SwitchOption interfaceStringFlav_suppressLeadingBOn
    (interfaceStringFlav_suppressLeadingB,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringFlav_suppressLeadingBOff
    (interfaceStringFlav_suppressLeadingB,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringFlav_lightLeadingBSup
    ("StringFlav_lightLeadingBSup",
     "  extra suppression of leading-baryon production for a light-quark  jet, i.e. \\f$d\\f$, \\f$u\\f$ or \\f$s\\f$, when  <code>suppressLeadingB = on</code>. Thus 0 means no leading-baryon  production at all, while 1 means full rate.  ",
     &StringFragmentation::theStringFlav_lightLeadingBSup, 0.5, 0., 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_heavyLeadingBSup
    ("StringFlav_heavyLeadingBSup",
     "  extra suppression of leading-baryon production for a heavy-quark  jet, i.e. \\f$c\\f$ or \\f$b\\f$, when  <code>suppressLeadingB = on</code>. Thus 0 means no leading-baryon  production at all, while 1 means full rate.  ",
     &StringFragmentation::theStringFlav_heavyLeadingBSup, 0.9, 0., 1.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_BtoMratio
    ("StringFlav_BtoMratio",
     "  Ratio of the relative rate of baryon to meson production, i.e. every  baryon Clebsch-Gordan coefficient gets multiplied by this factor.  ",
     &StringFragmentation::theStringFlav_BtoMratio, 0.357, 0.1, 10.0,
     true, false, Interface::limited);

  static Parameter<StringFragmentation,double> interfaceStringFlav_StrangeSuppression
    ("StringFlav_StrangeSuppression",
     "  Extra suppression factor for strange quarks. Note that in case of more  than one strange quark in the hadron the factor gets squared or tripled  respectively.  ",
     &StringFragmentation::theStringFlav_StrangeSuppression, 0.5, 0.01, 1.0,
     true, false, Interface::limited);

  static Switch<StringFragmentation,bool> interfaceStringFlav_mesonNonetL1
    ("StringFlav_mesonNonetL1",
     "  Switch on to include the pseudovector, scalar, pseudovector, and tensor  nonet (L=1).  ",
     &StringFragmentation::theStringFlav_mesonNonetL1, false, true, false);
  static SwitchOption interfaceStringFlav_mesonNonetL1On
    (interfaceStringFlav_mesonNonetL1,
     "On",
     "On",
     true);
  static SwitchOption interfaceStringFlav_mesonNonetL1Off
    (interfaceStringFlav_mesonNonetL1,
     "Off",
     "Off",
     false);

  static Parameter<StringFragmentation,double> interfaceStringFlav_kappa
    ("StringFlav_kappa",
     "  A base value of the string tension can be added, and modified along with other  parameters, to allow for studies of exotic quark production in the Rope model.  ",
     &StringFragmentation::theStringFlav_kappa, 0.2, 0.0, 10.,
     true, false, Interface::limited);

  static ParVector<StringFragmentation,string> interfaceAdditionalP8Settings
    ("AdditionalP8Settings",
     "Each string in this vector will be sent to the Pythia8 Settings "
     "object using the Pythia::readString function. Note that most relevant "
     "settings are already available as normal ThePEG interfaces, and that "
     "this interface should be used with care.",
     &StringFragmentation::theAdditionalP8Settings, -1, "", "", "",
     true, false, Interface::nolimits);

